@@ -40,6 +40,7 @@ from .type_defs import (
     CreateOutpostOutputTypeDef,
     CreateSiteOutputTypeDef,
     GetCatalogItemOutputTypeDef,
+    GetConnectionResponseTypeDef,
     GetOrderOutputTypeDef,
     GetOutpostInstanceTypesOutputTypeDef,
     GetOutpostOutputTypeDef,
@@ -53,6 +54,7 @@ from .type_defs import (
     ListSitesOutputTypeDef,
     ListTagsForResourceResponseTypeDef,
     RackPhysicalPropertiesTypeDef,
+    StartConnectionResponseTypeDef,
     UpdateOutpostOutputTypeDef,
     UpdateSiteAddressOutputTypeDef,
     UpdateSiteOutputTypeDef,
@@ -119,11 +121,19 @@ class OutpostsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#cancel_order)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#close)
+        """
+
     def create_order(
         self,
         *,
         OutpostIdentifier: str,
-        LineItems: Sequence["LineItemRequestTypeDef"],
+        LineItems: Sequence[LineItemRequestTypeDef],
         PaymentOption: PaymentOptionType,
         PaymentTerm: Literal["THREE_YEARS"] = ...
     ) -> CreateOrderOutputTypeDef:
@@ -159,9 +169,9 @@ class OutpostsClient(BaseClient):
         Description: str = ...,
         Notes: str = ...,
         Tags: Mapping[str, str] = ...,
-        OperatingAddress: "AddressTypeDef" = ...,
-        ShippingAddress: "AddressTypeDef" = ...,
-        RackPhysicalProperties: "RackPhysicalPropertiesTypeDef" = ...
+        OperatingAddress: AddressTypeDef = ...,
+        ShippingAddress: AddressTypeDef = ...,
+        RackPhysicalProperties: RackPhysicalPropertiesTypeDef = ...
     ) -> CreateSiteOutputTypeDef:
         """
         Creates a site for an Outpost.
@@ -208,6 +218,14 @@ class OutpostsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#get_catalog_item)
         """
 
+    def get_connection(self, *, ConnectionId: str) -> GetConnectionResponseTypeDef:
+        """
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.get_connection)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#get_connection)
+        """
+
     def get_order(self, *, OrderId: str) -> GetOrderOutputTypeDef:
         """
         Gets an order.
@@ -333,6 +351,21 @@ class OutpostsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#list_tags_for_resource)
         """
 
+    def start_connection(
+        self,
+        *,
+        DeviceSerialNumber: str,
+        AssetId: str,
+        ClientPublicKey: str,
+        NetworkInterfaceDeviceIndex: int
+    ) -> StartConnectionResponseTypeDef:
+        """
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/outposts.html#Outposts.Client.start_connection)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_outposts/client/#start_connection)
+        """
+
     def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Adds tags to the specified resource.
@@ -375,7 +408,7 @@ class OutpostsClient(BaseClient):
         """
 
     def update_site_address(
-        self, *, SiteId: str, AddressType: AddressTypeType, Address: "AddressTypeDef"
+        self, *, SiteId: str, AddressType: AddressTypeType, Address: AddressTypeDef
     ) -> UpdateSiteAddressOutputTypeDef:
         """
         Updates the site address.
