@@ -48,62 +48,68 @@ else:
 
 __all__ = (
     "AddressTypeDef",
-    "AssetInfoTypeDef",
-    "CancelOrderInputRequestTypeDef",
-    "CatalogItemTypeDef",
+    "AssetLocationTypeDef",
     "ComputeAttributesTypeDef",
-    "CreateOrderInputRequestTypeDef",
-    "CreateOrderOutputTypeDef",
-    "CreateOutpostInputRequestTypeDef",
-    "CreateOutpostOutputTypeDef",
-    "CreateSiteInputRequestTypeDef",
-    "CreateSiteOutputTypeDef",
-    "DeleteOutpostInputRequestTypeDef",
-    "DeleteSiteInputRequestTypeDef",
+    "CancelOrderInputRequestTypeDef",
     "EC2CapacityTypeDef",
-    "GetCatalogItemInputRequestTypeDef",
-    "GetCatalogItemOutputTypeDef",
-    "GetOrderInputRequestTypeDef",
-    "GetOrderOutputTypeDef",
-    "GetOutpostInputRequestTypeDef",
-    "GetOutpostInstanceTypesInputRequestTypeDef",
-    "GetOutpostInstanceTypesOutputTypeDef",
-    "GetOutpostOutputTypeDef",
-    "GetSiteAddressInputRequestTypeDef",
-    "GetSiteAddressOutputTypeDef",
-    "GetSiteInputRequestTypeDef",
-    "GetSiteOutputTypeDef",
-    "InstanceTypeItemTypeDef",
+    "ConnectionDetailsTypeDef",
     "LineItemRequestTypeDef",
-    "LineItemTypeDef",
-    "ListAssetsInputRequestTypeDef",
-    "ListAssetsOutputTypeDef",
-    "ListCatalogItemsInputRequestTypeDef",
-    "ListCatalogItemsOutputTypeDef",
-    "ListOrdersInputRequestTypeDef",
-    "ListOrdersOutputTypeDef",
-    "ListOutpostsInputRequestTypeDef",
-    "ListOutpostsOutputTypeDef",
-    "ListSitesInputRequestTypeDef",
-    "ListSitesOutputTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "OrderSummaryTypeDef",
-    "OrderTypeDef",
+    "ResponseMetadataTypeDef",
+    "CreateOutpostInputRequestTypeDef",
     "OutpostTypeDef",
     "RackPhysicalPropertiesTypeDef",
-    "ResponseMetadataTypeDef",
-    "SiteTypeDef",
+    "DeleteOutpostInputRequestTypeDef",
+    "DeleteSiteInputRequestTypeDef",
+    "GetCatalogItemInputRequestTypeDef",
+    "GetConnectionRequestRequestTypeDef",
+    "GetOrderInputRequestTypeDef",
+    "GetOutpostInputRequestTypeDef",
+    "GetOutpostInstanceTypesInputRequestTypeDef",
+    "InstanceTypeItemTypeDef",
+    "GetSiteAddressInputRequestTypeDef",
+    "GetSiteInputRequestTypeDef",
+    "LineItemTypeDef",
+    "ListAssetsInputRequestTypeDef",
+    "ListCatalogItemsInputRequestTypeDef",
+    "ListOrdersInputRequestTypeDef",
+    "OrderSummaryTypeDef",
+    "ListOutpostsInputRequestTypeDef",
+    "ListSitesInputRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "StartConnectionRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateOutpostInputRequestTypeDef",
-    "UpdateOutpostOutputTypeDef",
-    "UpdateSiteAddressInputRequestTypeDef",
-    "UpdateSiteAddressOutputTypeDef",
     "UpdateSiteInputRequestTypeDef",
-    "UpdateSiteOutputTypeDef",
     "UpdateSiteRackPhysicalPropertiesInputRequestTypeDef",
+    "UpdateSiteAddressInputRequestTypeDef",
+    "AssetInfoTypeDef",
+    "CatalogItemTypeDef",
+    "CreateOrderInputRequestTypeDef",
+    "GetConnectionResponseTypeDef",
+    "GetSiteAddressOutputTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "StartConnectionResponseTypeDef",
+    "UpdateSiteAddressOutputTypeDef",
+    "CreateOutpostOutputTypeDef",
+    "GetOutpostOutputTypeDef",
+    "ListOutpostsOutputTypeDef",
+    "UpdateOutpostOutputTypeDef",
+    "CreateSiteInputRequestTypeDef",
+    "SiteTypeDef",
+    "GetOutpostInstanceTypesOutputTypeDef",
+    "OrderTypeDef",
+    "ListOrdersOutputTypeDef",
+    "ListAssetsOutputTypeDef",
+    "GetCatalogItemOutputTypeDef",
+    "ListCatalogItemsOutputTypeDef",
+    "CreateSiteOutputTypeDef",
+    "GetSiteOutputTypeDef",
+    "ListSitesOutputTypeDef",
+    "UpdateSiteOutputTypeDef",
     "UpdateSiteRackPhysicalPropertiesOutputTypeDef",
+    "CreateOrderOutputTypeDef",
+    "GetOrderOutputTypeDef",
 )
 
 _RequiredAddressTypeDef = TypedDict(
@@ -134,34 +140,10 @@ class AddressTypeDef(_RequiredAddressTypeDef, _OptionalAddressTypeDef):
     pass
 
 
-AssetInfoTypeDef = TypedDict(
-    "AssetInfoTypeDef",
+AssetLocationTypeDef = TypedDict(
+    "AssetLocationTypeDef",
     {
-        "AssetId": str,
-        "RackId": str,
-        "AssetType": Literal["COMPUTE"],
-        "ComputeAttributes": "ComputeAttributesTypeDef",
-    },
-    total=False,
-)
-
-CancelOrderInputRequestTypeDef = TypedDict(
-    "CancelOrderInputRequestTypeDef",
-    {
-        "OrderId": str,
-    },
-)
-
-CatalogItemTypeDef = TypedDict(
-    "CatalogItemTypeDef",
-    {
-        "CatalogItemId": str,
-        "ItemStatus": CatalogItemStatusType,
-        "EC2Capacities": List["EC2CapacityTypeDef"],
-        "PowerKva": float,
-        "WeightLbs": int,
-        "SupportedUplinkGbps": List[int],
-        "SupportedStorage": List[SupportedStorageEnumType],
+        "RackElevation": float,
     },
     total=False,
 )
@@ -174,34 +156,53 @@ ComputeAttributesTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCreateOrderInputRequestTypeDef = TypedDict(
-    "_RequiredCreateOrderInputRequestTypeDef",
+CancelOrderInputRequestTypeDef = TypedDict(
+    "CancelOrderInputRequestTypeDef",
     {
-        "OutpostIdentifier": str,
-        "LineItems": Sequence["LineItemRequestTypeDef"],
-        "PaymentOption": PaymentOptionType,
+        "OrderId": str,
     },
 )
-_OptionalCreateOrderInputRequestTypeDef = TypedDict(
-    "_OptionalCreateOrderInputRequestTypeDef",
+
+EC2CapacityTypeDef = TypedDict(
+    "EC2CapacityTypeDef",
     {
-        "PaymentTerm": Literal["THREE_YEARS"],
+        "Family": str,
+        "MaxSize": str,
+        "Quantity": str,
     },
     total=False,
 )
 
-
-class CreateOrderInputRequestTypeDef(
-    _RequiredCreateOrderInputRequestTypeDef, _OptionalCreateOrderInputRequestTypeDef
-):
-    pass
-
-
-CreateOrderOutputTypeDef = TypedDict(
-    "CreateOrderOutputTypeDef",
+ConnectionDetailsTypeDef = TypedDict(
+    "ConnectionDetailsTypeDef",
     {
-        "Order": "OrderTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "ClientPublicKey": str,
+        "ServerPublicKey": str,
+        "ServerEndpoint": str,
+        "ClientTunnelAddress": str,
+        "ServerTunnelAddress": str,
+        "AllowedIps": List[str],
+    },
+    total=False,
+)
+
+LineItemRequestTypeDef = TypedDict(
+    "LineItemRequestTypeDef",
+    {
+        "CatalogItemId": str,
+        "Quantity": int,
+    },
+    total=False,
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -231,369 +232,6 @@ class CreateOutpostInputRequestTypeDef(
     pass
 
 
-CreateOutpostOutputTypeDef = TypedDict(
-    "CreateOutpostOutputTypeDef",
-    {
-        "Outpost": "OutpostTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredCreateSiteInputRequestTypeDef = TypedDict(
-    "_RequiredCreateSiteInputRequestTypeDef",
-    {
-        "Name": str,
-    },
-)
-_OptionalCreateSiteInputRequestTypeDef = TypedDict(
-    "_OptionalCreateSiteInputRequestTypeDef",
-    {
-        "Description": str,
-        "Notes": str,
-        "Tags": Mapping[str, str],
-        "OperatingAddress": "AddressTypeDef",
-        "ShippingAddress": "AddressTypeDef",
-        "RackPhysicalProperties": "RackPhysicalPropertiesTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateSiteInputRequestTypeDef(
-    _RequiredCreateSiteInputRequestTypeDef, _OptionalCreateSiteInputRequestTypeDef
-):
-    pass
-
-
-CreateSiteOutputTypeDef = TypedDict(
-    "CreateSiteOutputTypeDef",
-    {
-        "Site": "SiteTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DeleteOutpostInputRequestTypeDef = TypedDict(
-    "DeleteOutpostInputRequestTypeDef",
-    {
-        "OutpostId": str,
-    },
-)
-
-DeleteSiteInputRequestTypeDef = TypedDict(
-    "DeleteSiteInputRequestTypeDef",
-    {
-        "SiteId": str,
-    },
-)
-
-EC2CapacityTypeDef = TypedDict(
-    "EC2CapacityTypeDef",
-    {
-        "Family": str,
-        "MaxSize": str,
-        "Quantity": str,
-    },
-    total=False,
-)
-
-GetCatalogItemInputRequestTypeDef = TypedDict(
-    "GetCatalogItemInputRequestTypeDef",
-    {
-        "CatalogItemId": str,
-    },
-)
-
-GetCatalogItemOutputTypeDef = TypedDict(
-    "GetCatalogItemOutputTypeDef",
-    {
-        "CatalogItem": "CatalogItemTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetOrderInputRequestTypeDef = TypedDict(
-    "GetOrderInputRequestTypeDef",
-    {
-        "OrderId": str,
-    },
-)
-
-GetOrderOutputTypeDef = TypedDict(
-    "GetOrderOutputTypeDef",
-    {
-        "Order": "OrderTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetOutpostInputRequestTypeDef = TypedDict(
-    "GetOutpostInputRequestTypeDef",
-    {
-        "OutpostId": str,
-    },
-)
-
-_RequiredGetOutpostInstanceTypesInputRequestTypeDef = TypedDict(
-    "_RequiredGetOutpostInstanceTypesInputRequestTypeDef",
-    {
-        "OutpostId": str,
-    },
-)
-_OptionalGetOutpostInstanceTypesInputRequestTypeDef = TypedDict(
-    "_OptionalGetOutpostInstanceTypesInputRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-
-class GetOutpostInstanceTypesInputRequestTypeDef(
-    _RequiredGetOutpostInstanceTypesInputRequestTypeDef,
-    _OptionalGetOutpostInstanceTypesInputRequestTypeDef,
-):
-    pass
-
-
-GetOutpostInstanceTypesOutputTypeDef = TypedDict(
-    "GetOutpostInstanceTypesOutputTypeDef",
-    {
-        "InstanceTypes": List["InstanceTypeItemTypeDef"],
-        "NextToken": str,
-        "OutpostId": str,
-        "OutpostArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetOutpostOutputTypeDef = TypedDict(
-    "GetOutpostOutputTypeDef",
-    {
-        "Outpost": "OutpostTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetSiteAddressInputRequestTypeDef = TypedDict(
-    "GetSiteAddressInputRequestTypeDef",
-    {
-        "SiteId": str,
-        "AddressType": AddressTypeType,
-    },
-)
-
-GetSiteAddressOutputTypeDef = TypedDict(
-    "GetSiteAddressOutputTypeDef",
-    {
-        "SiteId": str,
-        "AddressType": AddressTypeType,
-        "Address": "AddressTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetSiteInputRequestTypeDef = TypedDict(
-    "GetSiteInputRequestTypeDef",
-    {
-        "SiteId": str,
-    },
-)
-
-GetSiteOutputTypeDef = TypedDict(
-    "GetSiteOutputTypeDef",
-    {
-        "Site": "SiteTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-InstanceTypeItemTypeDef = TypedDict(
-    "InstanceTypeItemTypeDef",
-    {
-        "InstanceType": str,
-    },
-    total=False,
-)
-
-LineItemRequestTypeDef = TypedDict(
-    "LineItemRequestTypeDef",
-    {
-        "CatalogItemId": str,
-        "Quantity": int,
-    },
-    total=False,
-)
-
-LineItemTypeDef = TypedDict(
-    "LineItemTypeDef",
-    {
-        "CatalogItemId": str,
-        "LineItemId": str,
-        "Quantity": int,
-        "Status": LineItemStatusType,
-    },
-    total=False,
-)
-
-_RequiredListAssetsInputRequestTypeDef = TypedDict(
-    "_RequiredListAssetsInputRequestTypeDef",
-    {
-        "OutpostIdentifier": str,
-    },
-)
-_OptionalListAssetsInputRequestTypeDef = TypedDict(
-    "_OptionalListAssetsInputRequestTypeDef",
-    {
-        "HostIdFilter": Sequence[str],
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListAssetsInputRequestTypeDef(
-    _RequiredListAssetsInputRequestTypeDef, _OptionalListAssetsInputRequestTypeDef
-):
-    pass
-
-
-ListAssetsOutputTypeDef = TypedDict(
-    "ListAssetsOutputTypeDef",
-    {
-        "Assets": List["AssetInfoTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListCatalogItemsInputRequestTypeDef = TypedDict(
-    "ListCatalogItemsInputRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-        "ItemClassFilter": Sequence[CatalogItemClassType],
-        "SupportedStorageFilter": Sequence[SupportedStorageEnumType],
-        "EC2FamilyFilter": Sequence[str],
-    },
-    total=False,
-)
-
-ListCatalogItemsOutputTypeDef = TypedDict(
-    "ListCatalogItemsOutputTypeDef",
-    {
-        "CatalogItems": List["CatalogItemTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListOrdersInputRequestTypeDef = TypedDict(
-    "ListOrdersInputRequestTypeDef",
-    {
-        "OutpostIdentifierFilter": str,
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-ListOrdersOutputTypeDef = TypedDict(
-    "ListOrdersOutputTypeDef",
-    {
-        "Orders": List["OrderSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListOutpostsInputRequestTypeDef = TypedDict(
-    "ListOutpostsInputRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-        "LifeCycleStatusFilter": Sequence[str],
-        "AvailabilityZoneFilter": Sequence[str],
-        "AvailabilityZoneIdFilter": Sequence[str],
-    },
-    total=False,
-)
-
-ListOutpostsOutputTypeDef = TypedDict(
-    "ListOutpostsOutputTypeDef",
-    {
-        "Outposts": List["OutpostTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListSitesInputRequestTypeDef = TypedDict(
-    "ListSitesInputRequestTypeDef",
-    {
-        "NextToken": str,
-        "MaxResults": int,
-        "OperatingAddressCountryCodeFilter": Sequence[str],
-        "OperatingAddressStateOrRegionFilter": Sequence[str],
-        "OperatingAddressCityFilter": Sequence[str],
-    },
-    total=False,
-)
-
-ListSitesOutputTypeDef = TypedDict(
-    "ListSitesOutputTypeDef",
-    {
-        "Sites": List["SiteTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
-    {
-        "ResourceArn": str,
-    },
-)
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-OrderSummaryTypeDef = TypedDict(
-    "OrderSummaryTypeDef",
-    {
-        "OutpostId": str,
-        "OrderId": str,
-        "OrderType": OrderTypeType,
-        "Status": OrderStatusType,
-        "LineItemCountsByStatus": Dict[LineItemStatusType, int],
-        "OrderSubmissionDate": datetime,
-        "OrderFulfilledDate": datetime,
-    },
-    total=False,
-)
-
-OrderTypeDef = TypedDict(
-    "OrderTypeDef",
-    {
-        "OutpostId": str,
-        "OrderId": str,
-        "Status": OrderStatusType,
-        "LineItems": List["LineItemTypeDef"],
-        "PaymentOption": PaymentOptionType,
-        "OrderSubmissionDate": datetime,
-        "OrderFulfilledDate": datetime,
-    },
-    total=False,
-)
-
 OutpostTypeDef = TypedDict(
     "OutpostTypeDef",
     {
@@ -629,35 +267,205 @@ RackPhysicalPropertiesTypeDef = TypedDict(
     total=False,
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+DeleteOutpostInputRequestTypeDef = TypedDict(
+    "DeleteOutpostInputRequestTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "OutpostId": str,
     },
 )
 
-SiteTypeDef = TypedDict(
-    "SiteTypeDef",
+DeleteSiteInputRequestTypeDef = TypedDict(
+    "DeleteSiteInputRequestTypeDef",
     {
         "SiteId": str,
-        "AccountId": str,
-        "Name": str,
-        "Description": str,
-        "Tags": Dict[str, str],
-        "SiteArn": str,
-        "Notes": str,
-        "OperatingAddressCountryCode": str,
-        "OperatingAddressStateOrRegion": str,
-        "OperatingAddressCity": str,
-        "RackPhysicalProperties": "RackPhysicalPropertiesTypeDef",
+    },
+)
+
+GetCatalogItemInputRequestTypeDef = TypedDict(
+    "GetCatalogItemInputRequestTypeDef",
+    {
+        "CatalogItemId": str,
+    },
+)
+
+GetConnectionRequestRequestTypeDef = TypedDict(
+    "GetConnectionRequestRequestTypeDef",
+    {
+        "ConnectionId": str,
+    },
+)
+
+GetOrderInputRequestTypeDef = TypedDict(
+    "GetOrderInputRequestTypeDef",
+    {
+        "OrderId": str,
+    },
+)
+
+GetOutpostInputRequestTypeDef = TypedDict(
+    "GetOutpostInputRequestTypeDef",
+    {
+        "OutpostId": str,
+    },
+)
+
+_RequiredGetOutpostInstanceTypesInputRequestTypeDef = TypedDict(
+    "_RequiredGetOutpostInstanceTypesInputRequestTypeDef",
+    {
+        "OutpostId": str,
+    },
+)
+_OptionalGetOutpostInstanceTypesInputRequestTypeDef = TypedDict(
+    "_OptionalGetOutpostInstanceTypesInputRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
+
+class GetOutpostInstanceTypesInputRequestTypeDef(
+    _RequiredGetOutpostInstanceTypesInputRequestTypeDef,
+    _OptionalGetOutpostInstanceTypesInputRequestTypeDef,
+):
+    pass
+
+
+InstanceTypeItemTypeDef = TypedDict(
+    "InstanceTypeItemTypeDef",
+    {
+        "InstanceType": str,
+    },
+    total=False,
+)
+
+GetSiteAddressInputRequestTypeDef = TypedDict(
+    "GetSiteAddressInputRequestTypeDef",
+    {
+        "SiteId": str,
+        "AddressType": AddressTypeType,
+    },
+)
+
+GetSiteInputRequestTypeDef = TypedDict(
+    "GetSiteInputRequestTypeDef",
+    {
+        "SiteId": str,
+    },
+)
+
+LineItemTypeDef = TypedDict(
+    "LineItemTypeDef",
+    {
+        "CatalogItemId": str,
+        "LineItemId": str,
+        "Quantity": int,
+        "Status": LineItemStatusType,
+    },
+    total=False,
+)
+
+_RequiredListAssetsInputRequestTypeDef = TypedDict(
+    "_RequiredListAssetsInputRequestTypeDef",
+    {
+        "OutpostIdentifier": str,
+    },
+)
+_OptionalListAssetsInputRequestTypeDef = TypedDict(
+    "_OptionalListAssetsInputRequestTypeDef",
+    {
+        "HostIdFilter": Sequence[str],
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAssetsInputRequestTypeDef(
+    _RequiredListAssetsInputRequestTypeDef, _OptionalListAssetsInputRequestTypeDef
+):
+    pass
+
+
+ListCatalogItemsInputRequestTypeDef = TypedDict(
+    "ListCatalogItemsInputRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "ItemClassFilter": Sequence[CatalogItemClassType],
+        "SupportedStorageFilter": Sequence[SupportedStorageEnumType],
+        "EC2FamilyFilter": Sequence[str],
+    },
+    total=False,
+)
+
+ListOrdersInputRequestTypeDef = TypedDict(
+    "ListOrdersInputRequestTypeDef",
+    {
+        "OutpostIdentifierFilter": str,
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+OrderSummaryTypeDef = TypedDict(
+    "OrderSummaryTypeDef",
+    {
+        "OutpostId": str,
+        "OrderId": str,
+        "OrderType": OrderTypeType,
+        "Status": OrderStatusType,
+        "LineItemCountsByStatus": Dict[LineItemStatusType, int],
+        "OrderSubmissionDate": datetime,
+        "OrderFulfilledDate": datetime,
+    },
+    total=False,
+)
+
+ListOutpostsInputRequestTypeDef = TypedDict(
+    "ListOutpostsInputRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "LifeCycleStatusFilter": Sequence[str],
+        "AvailabilityZoneFilter": Sequence[str],
+        "AvailabilityZoneIdFilter": Sequence[str],
+    },
+    total=False,
+)
+
+ListSitesInputRequestTypeDef = TypedDict(
+    "ListSitesInputRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "OperatingAddressCountryCodeFilter": Sequence[str],
+        "OperatingAddressStateOrRegionFilter": Sequence[str],
+        "OperatingAddressCityFilter": Sequence[str],
+    },
+    total=False,
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
+StartConnectionRequestRequestTypeDef = TypedDict(
+    "StartConnectionRequestRequestTypeDef",
+    {
+        "DeviceSerialNumber": str,
+        "AssetId": str,
+        "ClientPublicKey": str,
+        "NetworkInterfaceDeviceIndex": int,
+    },
+)
+
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -697,32 +505,6 @@ class UpdateOutpostInputRequestTypeDef(
     pass
 
 
-UpdateOutpostOutputTypeDef = TypedDict(
-    "UpdateOutpostOutputTypeDef",
-    {
-        "Outpost": "OutpostTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-UpdateSiteAddressInputRequestTypeDef = TypedDict(
-    "UpdateSiteAddressInputRequestTypeDef",
-    {
-        "SiteId": str,
-        "AddressType": AddressTypeType,
-        "Address": "AddressTypeDef",
-    },
-)
-
-UpdateSiteAddressOutputTypeDef = TypedDict(
-    "UpdateSiteAddressOutputTypeDef",
-    {
-        "AddressType": AddressTypeType,
-        "Address": "AddressTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateSiteInputRequestTypeDef = TypedDict(
     "_RequiredUpdateSiteInputRequestTypeDef",
     {
@@ -746,14 +528,6 @@ class UpdateSiteInputRequestTypeDef(
     pass
 
 
-UpdateSiteOutputTypeDef = TypedDict(
-    "UpdateSiteOutputTypeDef",
-    {
-        "Site": "SiteTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateSiteRackPhysicalPropertiesInputRequestTypeDef = TypedDict(
     "_RequiredUpdateSiteRackPhysicalPropertiesInputRequestTypeDef",
     {
@@ -784,10 +558,299 @@ class UpdateSiteRackPhysicalPropertiesInputRequestTypeDef(
     pass
 
 
+UpdateSiteAddressInputRequestTypeDef = TypedDict(
+    "UpdateSiteAddressInputRequestTypeDef",
+    {
+        "SiteId": str,
+        "AddressType": AddressTypeType,
+        "Address": AddressTypeDef,
+    },
+)
+
+AssetInfoTypeDef = TypedDict(
+    "AssetInfoTypeDef",
+    {
+        "AssetId": str,
+        "RackId": str,
+        "AssetType": Literal["COMPUTE"],
+        "ComputeAttributes": ComputeAttributesTypeDef,
+        "AssetLocation": AssetLocationTypeDef,
+    },
+    total=False,
+)
+
+CatalogItemTypeDef = TypedDict(
+    "CatalogItemTypeDef",
+    {
+        "CatalogItemId": str,
+        "ItemStatus": CatalogItemStatusType,
+        "EC2Capacities": List[EC2CapacityTypeDef],
+        "PowerKva": float,
+        "WeightLbs": int,
+        "SupportedUplinkGbps": List[int],
+        "SupportedStorage": List[SupportedStorageEnumType],
+    },
+    total=False,
+)
+
+_RequiredCreateOrderInputRequestTypeDef = TypedDict(
+    "_RequiredCreateOrderInputRequestTypeDef",
+    {
+        "OutpostIdentifier": str,
+        "LineItems": Sequence[LineItemRequestTypeDef],
+        "PaymentOption": PaymentOptionType,
+    },
+)
+_OptionalCreateOrderInputRequestTypeDef = TypedDict(
+    "_OptionalCreateOrderInputRequestTypeDef",
+    {
+        "PaymentTerm": Literal["THREE_YEARS"],
+    },
+    total=False,
+)
+
+
+class CreateOrderInputRequestTypeDef(
+    _RequiredCreateOrderInputRequestTypeDef, _OptionalCreateOrderInputRequestTypeDef
+):
+    pass
+
+
+GetConnectionResponseTypeDef = TypedDict(
+    "GetConnectionResponseTypeDef",
+    {
+        "ConnectionId": str,
+        "ConnectionDetails": ConnectionDetailsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetSiteAddressOutputTypeDef = TypedDict(
+    "GetSiteAddressOutputTypeDef",
+    {
+        "SiteId": str,
+        "AddressType": AddressTypeType,
+        "Address": AddressTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartConnectionResponseTypeDef = TypedDict(
+    "StartConnectionResponseTypeDef",
+    {
+        "ConnectionId": str,
+        "UnderlayIpAddress": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateSiteAddressOutputTypeDef = TypedDict(
+    "UpdateSiteAddressOutputTypeDef",
+    {
+        "AddressType": AddressTypeType,
+        "Address": AddressTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateOutpostOutputTypeDef = TypedDict(
+    "CreateOutpostOutputTypeDef",
+    {
+        "Outpost": OutpostTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetOutpostOutputTypeDef = TypedDict(
+    "GetOutpostOutputTypeDef",
+    {
+        "Outpost": OutpostTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListOutpostsOutputTypeDef = TypedDict(
+    "ListOutpostsOutputTypeDef",
+    {
+        "Outposts": List[OutpostTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateOutpostOutputTypeDef = TypedDict(
+    "UpdateOutpostOutputTypeDef",
+    {
+        "Outpost": OutpostTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCreateSiteInputRequestTypeDef = TypedDict(
+    "_RequiredCreateSiteInputRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalCreateSiteInputRequestTypeDef = TypedDict(
+    "_OptionalCreateSiteInputRequestTypeDef",
+    {
+        "Description": str,
+        "Notes": str,
+        "Tags": Mapping[str, str],
+        "OperatingAddress": AddressTypeDef,
+        "ShippingAddress": AddressTypeDef,
+        "RackPhysicalProperties": RackPhysicalPropertiesTypeDef,
+    },
+    total=False,
+)
+
+
+class CreateSiteInputRequestTypeDef(
+    _RequiredCreateSiteInputRequestTypeDef, _OptionalCreateSiteInputRequestTypeDef
+):
+    pass
+
+
+SiteTypeDef = TypedDict(
+    "SiteTypeDef",
+    {
+        "SiteId": str,
+        "AccountId": str,
+        "Name": str,
+        "Description": str,
+        "Tags": Dict[str, str],
+        "SiteArn": str,
+        "Notes": str,
+        "OperatingAddressCountryCode": str,
+        "OperatingAddressStateOrRegion": str,
+        "OperatingAddressCity": str,
+        "RackPhysicalProperties": RackPhysicalPropertiesTypeDef,
+    },
+    total=False,
+)
+
+GetOutpostInstanceTypesOutputTypeDef = TypedDict(
+    "GetOutpostInstanceTypesOutputTypeDef",
+    {
+        "InstanceTypes": List[InstanceTypeItemTypeDef],
+        "NextToken": str,
+        "OutpostId": str,
+        "OutpostArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+OrderTypeDef = TypedDict(
+    "OrderTypeDef",
+    {
+        "OutpostId": str,
+        "OrderId": str,
+        "Status": OrderStatusType,
+        "LineItems": List[LineItemTypeDef],
+        "PaymentOption": PaymentOptionType,
+        "OrderSubmissionDate": datetime,
+        "OrderFulfilledDate": datetime,
+    },
+    total=False,
+)
+
+ListOrdersOutputTypeDef = TypedDict(
+    "ListOrdersOutputTypeDef",
+    {
+        "Orders": List[OrderSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListAssetsOutputTypeDef = TypedDict(
+    "ListAssetsOutputTypeDef",
+    {
+        "Assets": List[AssetInfoTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetCatalogItemOutputTypeDef = TypedDict(
+    "GetCatalogItemOutputTypeDef",
+    {
+        "CatalogItem": CatalogItemTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListCatalogItemsOutputTypeDef = TypedDict(
+    "ListCatalogItemsOutputTypeDef",
+    {
+        "CatalogItems": List[CatalogItemTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateSiteOutputTypeDef = TypedDict(
+    "CreateSiteOutputTypeDef",
+    {
+        "Site": SiteTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetSiteOutputTypeDef = TypedDict(
+    "GetSiteOutputTypeDef",
+    {
+        "Site": SiteTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListSitesOutputTypeDef = TypedDict(
+    "ListSitesOutputTypeDef",
+    {
+        "Sites": List[SiteTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateSiteOutputTypeDef = TypedDict(
+    "UpdateSiteOutputTypeDef",
+    {
+        "Site": SiteTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateSiteRackPhysicalPropertiesOutputTypeDef = TypedDict(
     "UpdateSiteRackPhysicalPropertiesOutputTypeDef",
     {
-        "Site": "SiteTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Site": SiteTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateOrderOutputTypeDef = TypedDict(
+    "CreateOrderOutputTypeDef",
+    {
+        "Order": OrderTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetOrderOutputTypeDef = TypedDict(
+    "GetOrderOutputTypeDef",
+    {
+        "Order": OrderTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
